@@ -454,11 +454,6 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 		e_source_set_property (source, "completion", "true");
 		if (folder->is_default) 
 			e_source_set_property (source, "delete", "no");
-		if (folder->parent_folder_id) {
-			gchar *tmp = exchange_mapi_util_mapi_id_to_string (folder->parent_folder_id);
-			e_source_set_property (source, "parent-fid", tmp);
-			g_free (tmp);
-		}
 		e_source_group_add_source (group, source, -1);
 		g_object_unref (source);
 	}
@@ -469,6 +464,7 @@ add_addressbook_sources (EAccount *account, GSList *folders)
 
 		uri = g_strdup_printf("mapigal://%s@%s/;Global Address List", url->user, url->host);
 		source = e_source_new_with_absolute_uri ("Global Address List", uri);
+		g_free (uri);
 		// source = e_source_new ("Global Address List", g_strconcat (";","Global Address List" , NULL));
 		e_source_set_property (source, "auth", "plain/password");
 		e_source_set_property (source, "auth-domain", "MAPIGAL");
@@ -686,7 +682,7 @@ mapi_account_changed (EAccountList *account_listener, EAccount *account)
 			gchar *profname = NULL, *uri = NULL; 
 			ExchangeMAPIAccountListener *config_listener = exchange_mapi_accounts_peek_config_listener();
 
-			profname = exchange_mapi_util_profile_name (new_url->user, camel_url_get_param (new_url, "domain"));
+			profname = g_strdup_printf("%s@%s", new_url->user, camel_url_get_param (new_url, "domain"));
 			camel_url_set_param(new_url, "profile", profname);
 			g_free (profname);
 
@@ -719,7 +715,7 @@ mapi_account_changed (EAccountList *account_listener, EAccount *account)
 				gchar *profname = NULL, *uri = NULL; 
 				ExchangeMAPIAccountListener *config_listener = exchange_mapi_accounts_peek_config_listener();
 
-				profname = exchange_mapi_util_profile_name (new_url->user, camel_url_get_param (new_url, "domain"));
+				profname = g_strdup_printf("%s@%s", new_url->user, camel_url_get_param (new_url, "domain"));
 				camel_url_set_param(new_url, "profile", profname);
 				g_free (profname);
 
